@@ -1,6 +1,6 @@
 from IPython.display import display, HTML
 
-class TableColor(Distribution):
+class TableColor():
     """ Class to color table
             
     """
